@@ -31,7 +31,7 @@ import logging
 log = logging.getLogger("cdd.PackageList")
 
 import apt_pkg
-apt_pkg.InitSystem()
+apt_pkg.init_system()
 
 
 # Constants to resolve_depends
@@ -590,10 +590,10 @@ def resolve_depends(from_list, with_lists, field=DEPENDS, fastFail=True):
 
 def allow_version(versionA, versionB, operator):
 	return {
-		"<<" : lambda a,b : a < b,
-		"<=" : lambda a,b : a <= b,
-		"=" : lambda a,b : a == b,
-		">=" : lambda a,b : a >= b,
-		">>" : lambda a,b : a > b,
+		"<" : lambda a,b : apt_pkg.version_compare(a,b) < 0,
+		"<=" : lambda a,b : apt_pkg.version_compare(a,b) <= 0,
+		"=" : lambda a,b : apt_pkg.version_compare(a,b) == 0,
+		">=" : lambda a,b : apt_pkg.version_compare(a,b) >= 0,
+		">" : lambda a,b : apt_pkg.version_compare(a,b) > 0,
 	}[operator](versionA, versionB)
 
